@@ -1,9 +1,10 @@
 from typing import Dict, Optional
 
+from asn1tools.codecs import oer, constraints_checker
+
 from asn1editor.controller.Controller import Controller
 from asn1editor.view.AbstractView import AbstractView, ChoiceView
 from asn1editor.view.AbstractViewFactory import AbstractViewFactory
-from asn1tools.codecs import oer, constraints_checker
 
 
 class ChoiceInstanceFactory:
@@ -20,13 +21,8 @@ class ChoiceInstanceFactory:
         from asn1editor.ViewControllerFactory import ViewControllerFactory
 
         if member != self._member:
-            self._view_factory.freeze()
-
             view_factory = ViewControllerFactory(self._view_factory)
 
             self._content_view = view_factory.create_view_and_controller(self._members[member], self._checkers[member], parent)
             self._member = member
             self._choice_view.set_view(self._content_view)
-            self._view_factory.update()
-
-            self._view_factory.thaw()
