@@ -53,10 +53,11 @@ class MenuHandler:
         menu_bar.Append(file_menu, '&File')
 
         view_menu = wx.Menu()
-        auto_view: wx.MenuItem = view_menu.Append(wx.ID_ANY, 'Automatic', kind=wx.ITEM_CHECK)
         groups_view: wx.MenuItem = view_menu.Append(wx.ID_ANY, 'Groups', kind=wx.ITEM_CHECK)
         tree_view: wx.MenuItem = view_menu.Append(wx.ID_ANY, 'Tree', kind=wx.ITEM_CHECK)
         tree_view.Check(True)
+        view_menu.AppendSeparator()
+        dark_mode: wx.MenuItem = view_menu.Append(wx.ID_ANY, 'Dark mode', kind=wx.ITEM_CHECK)
         menu_bar.Append(view_menu, '&View')
 
         self.__frame.SetMenuBar(menu_bar)
@@ -95,7 +96,7 @@ class MenuHandler:
                             toolbar.AddSeparator()
                         else:
                             bitmap = wx.Bitmap(plugin_resource_path(tool[2]))
-                            labels |= len(tool[0])
+                            labels |= len(tool[0]) > 0
                             toolbar.AddTool(toolId=plugin_index * 1000 + i, label=tool[0], bitmap=bitmap, shortHelp=tool[1])
                     if labels:
                         toolbar.SetWindowStyle(wx.TB_TEXT | wx.TB_HORIZONTAL)
@@ -136,7 +137,7 @@ class MenuHandler:
         picker = FilePickerHandler(data_save_dialog_constructor, save_data_to_file, True)
         self.__frame.Bind(wx.EVT_MENU, picker.on_menu_click, self.__save_data_item)
 
-        self.view_select = ViewSelect(self.__frame, auto_view, groups_view, tree_view, view_changed)
+        self.view_select = ViewSelect(self.__frame, groups_view, tree_view, dark_mode, view_changed)
 
     def enable(self, enable: bool = True):
         self.__load_data_item.Enable(enable)
